==> maven-license-plugin-2.4-sources.jar: org/nuiton/license/plugin/header/transformer/AptFileHeaderTransformer.java <==
/*
 * #%L
 * Maven License Plugin
 * 
 * $Id: AptFileHeaderTransformer.java 1832 2010-09-29 13:49:21Z ymartel $
 * $HeadURL: http://svn.nuiton.org/svn/maven-license-plugin/tags/maven-license-plugin-2.4/src/main/java/org/nuiton/license/plugin/header/transformer/AptFileHeaderTransformer.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.license.plugin.header.transformer;

/**
 * Implementation of {@link FileHeaderTransformer} for apt format.
 *
 * @author tchemit <chemit@codelutin.com>
 * @plexus.component role-hint="apt"
 * @since 2.1
 */
public class AptFileHeaderTransformer extends AbstractFileHeaderTransformer {

    public static final String NAME = "apt";

    public static final String DESCRIPTION = "header transformer with apt comment style";

    public static final String COMMENT_LINE_PREFIX = "~~ ";

    public static final String COMMENT_START_TAG = "~~~";

    public static final String COMMENT_END_TAG = "~~~";

    public AptFileHeaderTransformer() {
        super(NAME,
              DESCRIPTION,
              COMMENT_START_TAG,
              COMMENT_END_TAG,
              COMMENT_LINE_PREFIX
        );
    }

//    @Override
//    public String unboxComent(String header) {
//
//        StringBuilder buffer = new StringBuilder();
//        int prefixLength = getCommentLinePrefix().length();
//        for (String line : header.split(LINE_SEPARATOR + "")) {
//            if (line.isEmpty()) {
//
//                // not be unboxed, but just skipped
//                continue;
//            }
//            int index = line.indexOf(getCommentLinePrefix());
//            if (index > -1) {
//
//                // remove comment prefix
//                line = line.substring(index + prefixLength);
//            }
//            buffer.append(line).append(LINE_SEPARATOR);
//        }
//        return buffer.toString();
//    }
}

==> maven-license-plugin-2.4.1-sources.jar: org/nuiton/license/plugin/header/transformer/AptFileHeaderTransformer.java <==
/*
 * #%L
 * Maven License Plugin
 * 
 * $Id: AptFileHeaderTransformer.java 1857 2010-10-17 01:09:17Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/maven-license-plugin/tags/maven-license-plugin-2.4.1/src/main/java/org/nuiton/license/plugin/header/transformer/AptFileHeaderTransformer.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.license.plugin.header.transformer;

/**
 * Implementation of {@link FileHeaderTransformer} for apt format.
 *
 * @author tchemit <chemit@codelutin.com>
 * @plexus.component role-hint="apt"
 * @since 2.1
 */
public class AptFileHeaderTransformer extends AbstractFileHeaderTransformer {

    public static final String NAME = "apt";

    public static final String DESCRIPTION = "header transformer with apt comment style";

    public static final String COMMENT_LINE_PREFIX = "~~ ";

    public static final String COMMENT_START_TAG = "~~~";

    public static final String COMMENT_END_TAG = "~~~";

    public AptFileHeaderTransformer() {
        super(NAME,
              DESCRIPTION,
              COMMENT_START_TAG,
              COMMENT_END_TAG,
              COMMENT_LINE_PREFIX
        );
    }

    @Override
    public String[] getDefaultAcceptedExtensions() {
        return new String[]{"apt"};
    }
}
